@@ -775,56 +775,15 @@ QStringList supportedImageFormats()
 #endif
 }
 
-
-
-
+//直接搬运文管代码
 bool imageSupportWallPaper(const QString &path)
 {
-    bool iRet = false;
-    QStringList listsupportWallPaper;
-    listsupportWallPaper << "bmp"
-//                         << "cod"
-                         << "png"
-                         << "gif"
-                         << "ief"
-                         << "jpe"
-                         << "jpeg"
-                         << "jpg"
-                         << "jfif"
-//                         << "svg"
-                         << "tif"
-                         << "tiff"
-//                         << "ras"
-//                         << "cmx"
-//                         << "ico"
-//                         << "pnm"
-//                         << "pbm"
-//                         << "pgm"
-//                         << "ppm"
-//                         << "rgb"
-//                         << "xbm"
-//                         << "xpm"
-//                         << "xwd"
-                         ;
-    //
-    QImageReader reader(path);
-    if (reader.imageCount() > 0) {
-
-        //2020/11/12 bug54279
-        if (listsupportWallPaper.contains(reader.format().toLower()) && listsupportWallPaper.contains(QFileInfo(path).suffix().toLower())) {
-            iRet = true;
-        }
-        //20201012 lmh ico不支持设置壁纸
-//        else {
-//            const QString suffix = QFileInfo(path).suffix();
-//            if(suffix=="ico")
-//            {
-//                iRet=true;
-//            }
-//        }
-    }
-
-    return iRet;
+    QMimeDatabase db;
+    QMimeType mt = db.mimeTypeForFile(path, QMimeDatabase::MatchDefault);
+    return mt.name().startsWith("image")
+           && !mt.name().endsWith("svg+xml")
+           && !mt.name().endsWith("raf")
+           && !mt.name().endsWith("crw");
 }
 
 //bool suffixisImage(const QString &path)
@@ -881,6 +840,46 @@ bool isCanRemove(const QString &path)
     }
     return bRet;
 }
+
+/**
+ * @brief 取得图像缓存文件夹路径
+ */
+QString getCacheImagePath()
+{
+    return QDir::homePath() + "/.cache/deepin/deepin-image-viewer/cache_image";
+}
+
+/**
+ * @brief 初始化图像缓存文件夹并返回是否初始化成功
+ */
+bool initCacheImageFolder()
+{
+    QDir homeDir(QDir::homePath());
+    return homeDir.mkpath(".cache/deepin/deepin-image-viewer/cache_image");
+}
+
+/**
+ * @brief 清空图像缓存文件夹并返回是否清理成功，
+ *  在程序启动或打开文件时调用
+ */
+bool clearCacheImageFolder()
+{
+    QDir cacheDir(getCacheImagePath());
+    if (cacheDir.exists()) {
+        return cacheDir.removeRecursively();
+    }
+    return false;
+}
+
+/**
+ * @brief 返回图像缓存中是否缓存 \a fileName 文件
+ */
+bool checkCacheImage(const QString &fileName)
+{
+    QDir cacheDir(getCacheImagePath());
+    return cacheDir.exists(fileName);
+}
+
 }  // namespace image
 
 }  //namespace utils
