@@ -37,6 +37,7 @@
 #include "slideshow/slideshowpanel.h"
 #include "service/configsetter.h"
 #include "service/imagedataservice.h"
+#include "unionimage/imageutils.h"
 
 const QString IMAGE_TMPPATH =   QDir::homePath() +
                                 "/.config/deepin/deepin-image-viewer/";
@@ -121,6 +122,9 @@ LibViewPanel::LibViewPanel(AbstractTopToolbar *customToolbar, QWidget *parent)
 
 LibViewPanel::~LibViewPanel()
 {
+    // 清空图像缓存目录
+    Libutils::image::clearCacheImageFolder();
+
     if (m_bottomToolbar) {
         m_bottomToolbar->deleteLater();
         m_bottomToolbar = nullptr;
@@ -133,6 +137,10 @@ LibViewPanel::~LibViewPanel()
 
 void LibViewPanel::loadImage(const QString &path, QStringList paths)
 {
+    // 初始化图像缓存目录
+    Libutils::image::clearCacheImageFolder();
+    Libutils::image::initCacheImageFolder();
+
     QFileInfo info(path);
     m_topToolbar->setMiddleContent(info.fileName());
     //展示图片
@@ -472,11 +480,13 @@ void LibViewPanel::updateMenuContent(QString path)
 
         //ocr按钮,是否是动态图,todo
         DIconButton *OcrButton = m_bottomToolbar->getBottomtoolbarButton(imageViewerSpace::ButtonTypeOcr);
-        if (imageViewerSpace::ImageTypeDynamic != imageType && isPic && isReadable) {
-            appendAction(IdOcr, QObject::tr("Extract text"), ss("Extract text", "Alt+O"));
-            OcrButton->setEnabled(true);
-        } else {
-            OcrButton->setEnabled(false);
+        if (OcrButton != nullptr) {
+            if (imageViewerSpace::ImageTypeDynamic != imageType && isPic && isReadable) {
+                appendAction(IdOcr, QObject::tr("Extract text"), ss("Extract text", "Alt+O"));
+                OcrButton->setEnabled(true);
+            } else {
+                OcrButton->setEnabled(false);
+            }
         }
 
         //如果图片数量大于0才能有幻灯片
